pub fn run(code: &str) -> RenderedExpand description
Explain code. A known code renders what/why/next + a docs URL and exits
EXIT_OK; an unknown one lists the known codes on stderr
and exits EXIT_USAGE.
pub fn run(code: &str) -> RenderedExplain code. A known code renders what/why/next + a docs URL and exits
EXIT_OK; an unknown one lists the known codes on stderr
and exits EXIT_USAGE.